@@ -1,7 +1,8 @@
 import numpy as np
 from typing import Union
 from pathlib import Path
-from skimage.morphology import remove_small_objects, watershed, dilation, ball
+from skimage.morphology import remove_small_objects, dilation, ball
+from skimage.segmentation import watershed
 from aicssegmentation.core.pre_processing_utils import (
     intensity_normalization,
     image_smoothing_gaussian_slice_by_slice,
